abacusai.api_class.model — AbacusAI documentation

# `abacusai.api_class.model`

## Module Contents

### Classes

`TrainingConfig` | Helper class that provides a standard way to create an ABC using
`PersonalizationTrainingConfig` | Training config for the PERSONALIZATION problem type
`RegressionTrainingConfig` | Training config for the PREDICTIVE_MODELING problem type
`ForecastingTrainingConfig` | Training config for the FORECASTING problem type
`NamedEntityExtractionTrainingConfig` | Training config for the NAMED_ENTITY_EXTRACTION problem type
`NaturalLanguageSearchTrainingConfig` | Training config for the NATURAL_LANGUAGE_SEARCH problem type
`ChatLLMTrainingConfig` | Training config for the CHAT_LLM problem type
`SentenceBoundaryDetectionTrainingConfig` | Training config for the SENTENCE_BOUNDARY_DETECTION problem type
`SentimentDetectionTrainingConfig` | Training config for the SENTIMENT_DETECTION problem type
`DocumentClassificationTrainingConfig` | Training config for the DOCUMENT_CLASSIFICATION problem type
`DocumentSummarizationTrainingConfig` | Training config for the DOCUMENT_SUMMARIZATION problem type
`DocumentVisualizationTrainingConfig` | Training config for the DOCUMENT_VISUALIZATION problem type
`ClusteringTrainingConfig` | Training config for the CLUSTERING problem type
`ClusteringTimeseriesTrainingConfig` | Training config for the CLUSTERING_TIMESERIES problem type
`EventAnomalyTrainingConfig` | Training config for the EVENT_ANOMALY problem type
`CumulativeForecastingTrainingConfig` | Training config for the CUMULATIVE_FORECASTING problem type
`AnomalyDetectionTrainingConfig` | Training config for the ANOMALY_DETECTION problem type
`ThemeAnalysisTrainingConfig` | Training config for the THEME ANALYSIS problem type
`AIAgentTrainingConfig` | Training config for the AI_AGENT problem type
`CustomTrainedModelTrainingConfig` | Training config for the CUSTOM_TRAINED_MODEL problem type
`CustomAlgorithmTrainingConfig` | Training config for the CUSTOM_ALGORITHM problem type
`OptimizationTrainingConfig` | Training config for the OPTIMIZATION problem type
`_TrainingConfigFactory` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.model.TrainingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  _upper_snake_case_keys: bool
  _support_kwargs: bool
  kwargs: dict
  problem_type: abacusai.api_class.enums.ProblemType
  algorithm: str
  classmethod _get_builder()

class abacusai.api_class.model.PersonalizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the PERSONALIZATION problem type :param objective: Ranking scheme used to select final best model. :type objective: PersonalizationObjective :param sort_objective: Ranking scheme used to sort models on the metrics page. :type sort_objective: PersonalizationObjective :param training_mode: whether to train in production or experimental mode. Defaults to EXP. :type training_mode: PersonalizationTrainingMode :param target_action_types: List of action types to use as targets for training. :type target_action_types: List[str] :param target_action_weights: Dictionary of action types to weights for training. :type target_action_weights: Dict[str, float] :param session_event_types: List of event types to treat as occurrences of sessions. :type session_event_types: List[str] :param test_split: Percent of dataset to use for test data. We support using a range between 6% to 20% of your dataset to use as test data. :type test_split: int :param recent_days_for_training: Limit training data to a certain latest number of days. :type recent_days_for_training: int :param training_start_date: Only consider training interaction data after this date. Specified in the timezone of the dataset. :type training_start_date: str :param test_on_user_split: Use user splits instead of using time splits, when validating and testing the model. :type test_on_user_split: bool :param test_split_on_last_k_items: Use last k items instead of global timestamp splits, when validating and testing the model. :type test_split_on_last_k_items: bool :param test_last_items_length: Number of items to leave out for each user when using leave k out folds. :type test_last_items_length: int :param test_window_length_hours: Duration (in hours) of most recent time window to use when validating and testing the model. :type test_window_length_hours: int :param explicit_time_split: Sets an explicit time-based test boundary. :type explicit_time_split: bool :param test_row_indicator: Column indicating which rows to use for training (TRAIN), validation (VAL) and testing (TEST). :type test_row_indicator: str :param full_data_retraining: Train models separately with all the data. :type full_data_retraining: bool :param sequential_training: Train a mode sequentially through time. :type sequential_training: bool :param data_split_feature_group_table_name: Specify the table name of the feature group to export training data with the fold column. :type data_split_feature_group_table_name: str :param optimized_event_type: The final event type to optimize for and compute metrics on. :type optimized_event_type: str :param dropout_rate: Dropout rate for neural network. :type dropout_rate: int :param batch_size: Batch size for neural network. :type batch_size: BatchSize :param disable_transformer: Disable training the transformer algorithm. :type disable_transformer: bool :param disable_gpu: Disable training on GPU. :type disable_gpu: boo :param filter_history: Do not recommend items the user has already interacted with. :type filter_history: bool :param max_history_length: Maximum length of user-item history to include user in training examples. :type max_history_length: int :param compute_rerank_metrics: Compute metrics based on rerank results. :type compute_rerank_metrics: bool :param add_time_features: Include interaction time as a feature. :type add_time_features: bool :param disable_timestamp_scalar_features: Exclude timestamp scalar features. :type disable_timestamp_scalar_features: bool :param compute_session_metrics: Evaluate models based on how well they are able to predict the next session of interactions. :type compute_session_metrics: bool :param max_user_history_len_percentile: Filter out users with history length above this percentile. :type max_user_history_len_percentile: int :param downsample_item_popularity_percentile: Downsample items more popular than this percentile. :type downsample_item_popularity_percentile: float

  objective: abacusai.api_class.enums.PersonalizationObjective
  sort_objective: abacusai.api_class.enums.PersonalizationObjective
  training_mode: abacusai.api_class.enums.PersonalizationTrainingMode
  target_action_types: List[str]
  target_action_weights: Dict[str, float]
  session_event_types: List[str]
  test_split: int
  recent_days_for_training: int
  training_start_date: str
  test_on_user_split: bool
  test_split_on_last_k_items: bool
  test_last_items_length: int
  test_window_length_hours: int
  explicit_time_split: bool
  test_row_indicator: str
  full_data_retraining: bool
  sequential_training: bool
  data_split_feature_group_table_name: str
  optimized_event_type: str
  dropout_rate: int
  batch_size: abacusai.api_class.enums.BatchSize
  disable_transformer: bool
  disable_gpu: bool
  filter_history: bool
  max_history_length: int
  compute_rerank_metrics: bool
  add_time_features: bool
  disable_timestamp_scalar_features: bool
  compute_session_metrics: bool
  max_user_history_len_percentile: int
  downsample_item_popularity_percentile: float
  __post_init__()

class abacusai.api_class.model.RegressionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the PREDICTIVE_MODELING problem type :param objective: Ranking scheme used to select final best model. :type objective: RegressionObjective :param sort_objective: Ranking scheme used to sort models on the metrics page. :type sort_objective: RegressionObjective :param tree_hpo_mode: (RegressionTreeHPOMode): Turning off Rapid Experimentation will take longer to train. :param type_of_split: Type of data splitting into train/test (validation also). :type type_of_split: RegressionTypeOfSplit :param test_split: Percent of dataset to use for test data. We support using a range between 5% to 20% of your dataset to use as test data. :type test_split: int :param disable_test_val_fold: Do not create a TEST_VAL set. All records which would be part of the TEST_VAL fold otherwise, remain in the TEST fold. :type disable_test_val_fold: bool :param k_fold_cross_validation: Use this to force k-fold cross validation bagging on or off. :type k_fold_cross_validation: bool :param num_cv_folds: Specify the value of k in k-fold cross validation. :type num_cv_folds: int :param timestamp_based_splitting_column: Timestamp column selected for splitting into test and train. :type timestamp_based_splitting_column: str :param timestamp_based_splitting_method: Method of selecting TEST set, top percentile wise or after a given timestamp. :type timestamp_based_splitting_method: RegressionTimeSplitMethod :param test_splitting_timestamp: Rows with timestamp greater than this will be considered to be in the test set. :type test_splitting_timestamp: str :param sampling_unit_keys: Constrain train/test separation to partition a column. :type sampling_unit_keys: List[str] :param test_row_indicator: Column indicating which rows to use for training (TRAIN) and testing (TEST). Validation (VAL) can also be specified. :type test_row_indicator: str :param rebalance_classes: Class weights are computed as the inverse of the class frequency from the training dataset when this option is selected as “Yes”. It is useful when the classes in the dataset are unbalanced.

  > Re-balancing classes generally boosts recall at the cost of precision on rare classes.

  Parameters:

    - rare_class_augmentation_threshold (float) – Augments any rare class whose relative frequency with respect to the most frequent class is less than this threshold. Default = 0.1 for classification problems with rare classes.

    - augmentation_strategy (RegressionAugmentationStrategy) – Strategy to deal with class imbalance and data augmentation.

    - training_rows_downsample_ratio (float) – Uses this ratio to train on a sample of the dataset provided.

    - active_labels_column (str) – Specify a column to use as the active columns in a multi label setting.

    - min_categorical_count (int) – Minimum threshold to consider a value different from the unknown placeholder.

    - sample_weight (str) – Specify a column to use as the weight of a sample for training and eval.

    - numeric_clipping_percentile (float) – Uses this option to clip the top and bottom x percentile of numeric feature columns where x is the value of this option.

    - target_transform (RegressionTargetTransform) – Specify a transform (e.g. log, quantile) to apply to the target variable.

    - ignore_datetime_features (bool) – Remove all datetime features from the model. Useful while generalizing to different time periods.

    - max_text_words (int) – Maximum number of words to use from text fields.

    - perform_feature_selection (bool) – If enabled, additional algorithms which support feature selection as a pretraining step will be trained separately with the selected subset of features. The details about their selected features can be found in their respective logs.

    - feature_selection_intensity (int) – This determines the strictness with which features will be filtered out. 1 being very lenient (more features kept), 100 being very strict.

    - batch_size (BatchSize) – Batch size.

    - dropout_rate (int) – Dropout percentage rate.

    - pretrained_model_name (str) – Enable algorithms which process text using pretrained multilingual NLP models.

    - is_multilingual (bool) – Enable algorithms which process text using pretrained multilingual NLP models.

    - loss_function (RegressionLossFunction) – Loss function to be used as objective for model training.

    - loss_parameters (str) – Loss function params in format <key>=<value>;<key>=<value>;…..

    - target_encode_categoricals (bool) – Use this to turn target encoding on categorical features on or off.

    - drop_original_categoricals (bool) – This option helps us choose whether to also feed the original label encoded categorical columns to the mdoels along with their target encoded versions.

    - data_split_feature_group_table_name (str) – Specify the table name of the feature group to export training data with the fold column.

    - custom_loss_functions (List[str]) – Registered custom losses available for selection.

    - custom_metrics (List[str]) – Registered custom metrics available for selection.

  objective: abacusai.api_class.enums.RegressionObjective
  sort_objective: abacusai.api_class.enums.RegressionObjective
  tree_hpo_mode: abacusai.api_class.enums.RegressionTreeHPOMode
  type_of_split: abacusai.api_class.enums.RegressionTypeOfSplit
  test_split: int
  disable_test_val_fold: bool
  k_fold_cross_validation: bool
  num_cv_folds: int
  timestamp_based_splitting_column: str
  timestamp_based_splitting_method: abacusai.api_class.enums.RegressionTimeSplitMethod
  test_splitting_timestamp: str
  sampling_unit_keys: List[str]
  test_row_indicator: str
  rebalance_classes: bool
  rare_class_augmentation_threshold: float
  augmentation_strategy: abacusai.api_class.enums.RegressionAugmentationStrategy
  training_rows_downsample_ratio: float
  active_labels_column: str
  min_categorical_count: int
  sample_weight: str
  numeric_clipping_percentile: float
  target_transform: abacusai.api_class.enums.RegressionTargetTransform
  ignore_datetime_features: bool
  max_text_words: int
  perform_feature_selection: bool
  feature_selection_intensity: int
  batch_size: abacusai.api_class.enums.BatchSize
  dropout_rate: int
  pretrained_model_name: str
  is_multilingual: bool
  loss_function: abacusai.api_class.enums.RegressionLossFunction
  loss_parameters: str
  target_encode_categoricals: bool
  drop_original_categoricals: bool
  data_split_feature_group_table_name: str
  custom_loss_functions: List[str]
  custom_metrics: List[str]
  __post_init__()

class abacusai.api_class.model.ForecastingTrainingConfig

  Bases: `TrainingConfig`

  Training config for the FORECASTING problem type :param prediction_length: How many timesteps in the future to predict. :type prediction_length: int :param objective: Ranking scheme used to select final best model. :type objective: ForecastingObjective :param sort_objective: Ranking scheme used to sort models on the metrics page. :type sort_objective: ForecastingObjective :param forecast_frequency: Forecast frequency. :type forecast_frequency: ForecastingFrequency :param probability_quantiles: Prediction quantiles. :type probability_quantiles: List[float] :param force_prediction_length: Force length of test window to be the same as prediction length. :type force_prediction_length: int :param filter_items: Filter items with small history and volume. :type filter_items: bool :param enable_feature_selection: Enable feature selection. :type enable_feature_selection: bool :param enable_cold_start: Enable cold start forecasting by training/predicting for zero history items. :type enable_cold_start: bool :param enable_multiple_backtests: Whether to enable multiple backtesting or not. :type enable_multiple_backtests: bool :param num_backtesting_windows: Total backtesting windows to use for the training. :type num_backtesting_windows: int :param backtesting_window_step_size: Use this step size to shift backtesting windows for model training. :type backtesting_window_step_size: int :param full_data_retraining: Train models separately with all the data. :type full_data_retraining: bool :param additional_forecast_keys: List[str]: List of categoricals in timeseries that can act as multi-identifier. :param experimentation_mode: Selecting Thorough Experimentation will take longer to train. :type experimentation_mode: ExperimentationMode :param type_of_split: Type of data splitting into train/test. :type type_of_split: ForecastingDataSplitType :param test_by_item: Partition train/test data by item rather than time if true. :type test_by_item: bool :param test_start: Limit training data to dates before the given test start. :type test_start: str :param test_split: Percent of dataset to use for test data. We support using a range between 5% to 20% of your dataset to use as test data. :type test_split: int :param loss_function: Loss function for training neural network. :type loss_function: ForecastingLossFunction :param underprediction_weight: Weight for underpredictions :type underprediction_weight: float :param disable_networks_without_analytic_quantiles: Disable neural networks, which quantile functions do not have analytic expressions (e.g, mixture models) :type disable_networks_without_analytic_quantiles: bool :param initial_learning_rate: Initial learning rate. :type initial_learning_rate: float :param l2_regularization_factor: L2 regularization factor. :type l2_regularization_factor: float :param dropout_rate: Dropout percentage rate. :type dropout_rate: int :param recurrent_layers: Number of recurrent layers to stack in network. :type recurrent_layers: int :param recurrent_units: Number of units in each recurrent layer. :type recurrent_units: int :param convolutional_layers: Number of convolutional layers to stack on top of recurrent layers in network. :type convolutional_layers: int :param convolution_filters: Number of filters in each convolution. :type convolution_filters: int :param local_scaling_mode: Options to make NN inputs stationary in high dynamic range datasets. :type local_scaling_mode: ForecastingLocalScaling :param zero_predictor: Include subnetwork to classify points where target equals zero. :type zero_predictor: bool :param skip_missing: Make the RNN ignore missing entries rather instead of processing them. :type skip_missing: bool :param batch_size: Batch size. :type batch_size: ForecastingBatchSize :param batch_renormalization: Enable batch renormalization between layers. :type batch_renormalization: bool :param history_length: While training, how much history to consider. :type history_length: int :param prediction_step_size: Number of future periods to include in objective for each training sample. :type prediction_step_size: int :param training_point_overlap: Amount of overlap to allow between training samples. :type training_point_overlap: float :param max_scale_context: Maximum context to use for local scaling. :type max_scale_context: int :param quantiles_extension_method: Quantile extension method :type quantiles_extension_method: ForecastingQuanitlesExtensionMethod :param number_of_samples: Number of samples for ancestral simulation :type number_of_samples: int :param symmetrize_quantiles: Force symmetric quantiles (like in Gaussian distribution) :type symmetrize_quantiles: bool :param use_log_transforms: Apply logarithmic transformations to input data. :type use_log_transforms: bool :param smooth_history: Smooth (low pass filter) the timeseries. :type smooth_history: float :param skip_local_scale_target: Skip using per training/prediction window target scaling. :type skip_local_scale_target: bool :param timeseries_weight_column: If set, we use the values in this column from timeseries data to assign time dependent item weights during training and evaluation. :type timeseries_weight_column: str :param item_attributes_weight_column: If set, we use the values in this column from item attributes data to assign weights to items during training and evaluation. :type item_attributes_weight_column: str :param use_timeseries_weights_in_objective: If True, we include weights from column set as “TIMESERIES WEIGHT COLUMN” in objective functions. :type use_timeseries_weights_in_objective: bool :param use_item_weights_in_objective: If True, we include weights from column set as “ITEM ATTRIBUTES WEIGHT COLUMN” in objective functions. :type use_item_weights_in_objective: bool :param skip_timeseries_weight_scaling: If True, we will avoid normalizing the weights. :type skip_timeseries_weight_scaling: bool :param timeseries_loss_weight_column: Use value in this column to weight the loss while training. :type timeseries_loss_weight_column: str :param use_item_id: Include a feature to indicate the item being forecast. :type use_item_id: bool :param use_all_item_totals: Include as input total target across items. :type use_all_item_totals: bool :param handle_zeros_as_missing_values: If True, handle zero values in demand as missing data. :type handle_zeros_as_missing_values: bool :param datetime_holiday_calendars: Holiday calendars to augment training with. :type datetime_holiday_calendars: List[HolidayCalendars] :param fill_missing_values: Strategy for filling in missing values. :type fill_missing_values: List[dict] :param enable_clustering: Enable clustering in forecasting. :type enable_clustering: bool :param data_split_feature_group_table_name: Specify the table name of the feature group to export training data with the fold column. :type data_split_feature_group_table_name: str :param custom_loss_functions: Registered custom losses available for selection. :type custom_loss_functions: List[str] :param custom_metrics: Registered custom metrics available for selection. :type custom_metrics: List[str]

  prediction_length: int
  objective: abacusai.api_class.enums.ForecastingObjective
  sort_objective: abacusai.api_class.enums.ForecastingObjective
  forecast_frequency: abacusai.api_class.enums.ForecastingFrequency
  probability_quantiles: List[float]
  force_prediction_length: bool
  filter_items: bool
  enable_feature_selection: bool
  enable_cold_start: bool
  enable_multiple_backtests: bool
  num_backtesting_windows: int
  backtesting_window_step_size: int
  full_data_retraining: bool
  additional_forecast_keys: List[str]
  experimentation_mode: abacusai.api_class.enums.ExperimentationMode
  type_of_split: abacusai.api_class.enums.ForecastingDataSplitType
  test_by_item: bool
  test_start: str
  test_split: int
  loss_function: abacusai.api_class.enums.ForecastingLossFunction
  underprediction_weight: float
  disable_networks_without_analytic_quantiles: bool
  initial_learning_rate: float
  l2_regularization_factor: float
  dropout_rate: int
  recurrent_layers: int
  recurrent_units: int
  convolutional_layers: int
  convolution_filters: int
  local_scaling_mode: abacusai.api_class.enums.ForecastingLocalScaling
  zero_predictor: bool
  skip_missing: bool
  batch_size: abacusai.api_class.enums.BatchSize
  batch_renormalization: bool
  history_length: int
  prediction_step_size: int
  training_point_overlap: float
  max_scale_context: int
  quantiles_extension_method: abacusai.api_class.enums.ForecastingQuanitlesExtensionMethod
  number_of_samples: int
  symmetrize_quantiles: bool
  use_log_transforms: bool
  smooth_history: float
  skip_local_scale_target: bool
  timeseries_weight_column: str
  item_attributes_weight_column: str
  use_timeseries_weights_in_objective: bool
  use_item_weights_in_objective: bool
  skip_timeseries_weight_scaling: bool
  timeseries_loss_weight_column: str
  use_item_id: bool
  use_all_item_totals: bool
  handle_zeros_as_missing_values: bool
  datetime_holiday_calendars: List[abacusai.api_class.enums.HolidayCalendars]
  fill_missing_values: List[dict]
  enable_clustering: bool
  data_split_feature_group_table_name: str
  custom_loss_functions: List[str]
  custom_metrics: List[str]
  __post_init__()

class abacusai.api_class.model.NamedEntityExtractionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the NAMED_ENTITY_EXTRACTION problem type :param objective: Ranking scheme used to select final best model. :type objective: NERObjective :param sort_objective: Ranking scheme used to sort models on the metrics page. :type sort_objective: NERObjective :param ner_model_type: Type of NER model to use. :type ner_model_type: NERModelType :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int :param test_row_indicator: Column indicating which rows to use for training (TRAIN) and testing (TEST). :type test_row_indicator: str :param dropout_rate: Dropout rate for neural network. :type dropout_rate: float :param batch_size: Batch size for neural network. :type batch_size: BatchSize :param active_labels_column: Entities that have been marked in a particular text :type active_labels_column: str :param document_format: Format of the input documents. :type document_format: NLPDocumentFormat :param include_longformer: Whether to include the longformer model. :type include_longformer: bool

  objective: abacusai.api_class.enums.NERObjective
  sort_objective: abacusai.api_class.enums.NERObjective
  ner_model_type: abacusai.api_class.enums.NERModelType
  test_split: int
  test_row_indicator: str
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  active_labels_column: str
  document_format: abacusai.api_class.enums.NLPDocumentFormat
  include_longformer: bool
  __post_init__()

class abacusai.api_class.model.NaturalLanguageSearchTrainingConfig

  Bases: `TrainingConfig`

  Training config for the NATURAL_LANGUAGE_SEARCH problem type :param abacus_internal_model: Use a Abacus.AI LLM to answer questions about your data without using any external APIs :type abacus_internal_model: bool :param num_completion_tokens: Default for maximum number of tokens for chat answers. Reducing this will get faster responses which are more succinct :type num_completion_tokens: int :param larger_embeddings: Use a higher dimension embedding model. :type larger_embeddings: bool :param search_chunk_size: Chunk size for indexing the documents. :type search_chunk_size: int :param chunk_overlap_fraction: Overlap in chunks while indexing the documents. :type chunk_overlap_fraction: float :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int

  abacus_internal_model: bool
  num_completion_tokens: int
  larger_embeddings: bool
  search_chunk_size: int
  index_fraction: float
  chunk_overlap_fraction: float
  __post_init__()

class abacusai.api_class.model.ChatLLMTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CHAT_LLM problem type :param document_retrievers: List of document retriever names to use for the feature stores this model was trained with. :type document_retrievers: List[str] :param num_completion_tokens: Default for maximum number of tokens for chat answers. Reducing this will get faster responses which are more succinct :type num_completion_tokens: int :param system_message: The generative LLM system message :type system_message: str :param temperature: The generative LLM temperature :type temperature: float :param metadata_columns: Include the metadata column values in the retrieved search results. :type metadata_columns: list

  document_retrievers: List[str]
  num_completion_tokens: int
  system_message: str
  temperature: float
  metadata_columns: list
  __post_init__()

class abacusai.api_class.model.SentenceBoundaryDetectionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the SENTENCE_BOUNDARY_DETECTION problem type :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int :param dropout_rate: Dropout rate for neural network. :type dropout_rate: float :param batch_size: Batch size for neural network. :type batch_size: BatchSize

  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.model.SentimentDetectionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the SENTIMENT_DETECTION problem type :param sentiment_type: Type of sentiment to detect. :type sentiment_type: SentimentType :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int :param dropout_rate: Dropout rate for neural network. :type dropout_rate: float :param batch_size: Batch size for neural network. :type batch_size: BatchSize :param compute_metrics: Whether to compute metrics. :type compute_metrics: bool

  sentiment_type: abacusai.api_class.enums.SentimentType
  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  compute_metrics: bool
  __post_init__()

class abacusai.api_class.model.DocumentClassificationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the DOCUMENT_CLASSIFICATION problem type :param zero_shot_hypotheses: Zero shot hypotheses. Example text: ‘This text is about pricing’. :type zero_shot_hypotheses: List[str] :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int :param dropout_rate: Dropout rate for neural network. :type dropout_rate: float :param batch_size: Batch size for neural network. :type batch_size: BatchSize

  zero_shot_hypotheses: List[str]
  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.model.DocumentSummarizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the DOCUMENT_SUMMARIZATION problem type :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int :param dropout_rate: Dropout rate for neural network. :type dropout_rate: float :param batch_size: Batch size for neural network. :type batch_size: BatchSize

  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.model.DocumentVisualizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the DOCUMENT_VISUALIZATION problem type :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int :param dropout_rate: Dropout rate for neural network. :type dropout_rate: float :param batch_size: Batch size for neural network. :type batch_size: BatchSize

  test_split: int
  dropout_rate: float
  batch_size: abacusai.api_class.enums.BatchSize
  __post_init__()

class abacusai.api_class.model.ClusteringTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CLUSTERING problem type :param num_clusters_selection: Number of clusters. If None, will be selected automatically. :type num_clusters_selection: int

  num_clusters_selection: int
  __post_init__()

class abacusai.api_class.model.ClusteringTimeseriesTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CLUSTERING_TIMESERIES problem type :param num_clusters_selection: Number of clusters. If None, will be selected automatically. :type num_clusters_selection: int :param imputation: Imputation method for missing values. :type imputation: ClusteringImputationMethod

  num_clusters_selection: int
  imputation: abacusai.api_class.enums.ClusteringImputationMethod
  __post_init__()

class abacusai.api_class.model.EventAnomalyTrainingConfig

  Bases: `TrainingConfig`

  Training config for the EVENT_ANOMALY problem type :param anomaly_fraction: The fraction of the dataset to classify as anomalous, between 0 and 0.5 :type anomaly_fraction: float

  anomaly_fraction: float
  __post_init__()

class abacusai.api_class.model.CumulativeForecastingTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CUMULATIVE_FORECASTING problem type :param test_split: Percent of dataset to use for test data. We support using a range between 5 ( i.e. 5% ) to 20 ( i.e. 20% ) of your dataset. :type test_split: int :param historical_frequency: Forecast frequency :type historical_frequency: str :param cumulative_prediction_lengths: List of Cumulative Prediction Frequencies. Each prediction length must be between 1 and 365. :type cumulative_prediction_lengths: List[int] :param skip_input_transform: Avoid doing numeric scaling transformations on the input. :type skip_input_transform: bool :param skip_target_transform: Avoid doing numeric scaling transformations on the target. :type skip_target_transform: bool :param predict_residuals: Predict residuals instead of totals at each prediction step. :type predict_residuals: bool

  test_split: int
  historical_frequency: str
  cumulative_prediction_lengths: List[int]
  skip_input_transform: bool
  skip_target_transform: bool
  predict_residuals: bool
  __post_init__()

class abacusai.api_class.model.AnomalyDetectionTrainingConfig

  Bases: `TrainingConfig`

  Training config for the ANOMALY_DETECTION problem type :param test_split: Percent of dataset to use for test data. We support using a range between 5 (i.e. 5%) to 20 (i.e. 20%) of your dataset to use as test data. :type test_split: int :param value_high: Detect unusually high values. :type value_high: bool :param mixture_of_gaussians: Detect unusual combinations of values using mixture of Gaussians. :type mixture_of_gaussians: bool :param variational_autoencoder: Use variational autoencoder for anomaly detection. :type variational_autoencoder: bool :param spike_up: Detect outliers with a high value. :type spike_up: bool :param spike_down: Detect outliers with a low value. :type spike_down: bool :param trend_change: Detect changes to the trend. :type trend_change: bool

  test_split: int
  value_high: bool
  mixture_of_gaussians: bool
  variational_autoencoder: bool
  spike_up: bool
  spike_down: bool
  trend_change: bool
  __post_init__()

class abacusai.api_class.model.ThemeAnalysisTrainingConfig

  Bases: `TrainingConfig`

  Training config for the THEME ANALYSIS problem type

  __post_init__()

class abacusai.api_class.model.AIAgentTrainingConfig

  Bases: `TrainingConfig`

  Training config for the AI_AGENT problem type :param description: Description of the agent function. :type description: str :param enable_binary_input: If True, the agent will be able to accept binary data as inputs. :type enable_binary_input: bool

  description: str
  enable_binary_input: bool
  __post_init__()

class abacusai.api_class.model.CustomTrainedModelTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CUSTOM_TRAINED_MODEL problem type :param max_catalog_size: Maximum expected catalog size. :type max_catalog_size: int :param max_dimension: Maximum expected dimension of the catalog. :type max_dimension: int :param index_output_path: Fully qualified cloud location (GCS, S3, etc) to export snapshots of the embedding to. :type index_output_path: str :param docker_image_uri: Docker image URI. :type docker_image_uri: str :param service_port: Service port. :type service_port: int

  max_catalog_size: int
  max_dimension: int
  index_output_path: str
  docker_image_uri: str
  service_port: int
  __post_init__()

class abacusai.api_class.model.CustomAlgorithmTrainingConfig

  Bases: `TrainingConfig`

  Training config for the CUSTOM_ALGORITHM problem type :param train_function_name: The name of the train function. :type train_function_name: str :param predict_many_function_name: The name of the predict many function. :type predict_many_function_name: str :param training_input_tables: List of tables to use for training. :type training_input_tables: List[str] :param predict_function_name: Optional name of the predict function if the predict many function is not given. :type predict_function_name: str :param train_module_name: The name of the train module - only relevant if model is being uploaded from a zip file or github repositoty. :type train_module_name: str :param predict_module_name: The name of the predict module - only relevant if model is being uploaded from a zip file or github repositoty. :type predict_module_name: str :param test_split: Percent of dataset to use for test data. We support using a range between 6% to 20% of your dataset to use as test data. :type test_split: int

  train_function_name: str
  predict_many_function_name: str
  training_input_tables: List[str]
  predict_function_name: str
  train_module_name: str
  predict_module_name: str
  test_split: int
  __post_init__()

class abacusai.api_class.model.OptimizationTrainingConfig

  Bases: `TrainingConfig`

  Training config for the OPTIMIZATION problem type :param solve_time_limit: The maximum time in seconds to spend solving the problem. Accepts values between 0 and 86400. :type solve_time_limit: float

  solve_time_limit: float
  __post_init__()

class abacusai.api_class.model._TrainingConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'problem_type'
  config_class_map